//presetting PS2 controller

#include <PS2X_lib.h>  //for v1.6

/******************************************************************
 * set pins connected to PS2 controller:
 *   - 1e column: original 
 *   - 2e colmun: Stef?
 * replace pin numbers by the ones you use
 ******************************************************************/
#define PS2_DAT        13    
#define PS2_CMD        11
#define PS2_SEL        3
#define PS2_CLK        12

/******************************************************************
 * select modes of PS2 controller:
 *   - pressures = analog reading of push-butttons 
 *   - rumble    = motor rumbling
 * uncomment 1 of the lines for each mode selection
 ******************************************************************/
#define pressures   false
//#define pressures   false
//#define rumble      true
#define rumble      false

PS2X ps2x; // create PS2 Controller Class

//right now, the library does NOT support hot pluggable controllers, meaning 
//you must always either restart your Arduino after you connect the controller, 
//or call config_gamepad(pins) again after connecting the controller.

int error = 0;
byte type = 0;
byte vibrate = 0;

// Reset func 
void (* resetFunc) (void) = 0;

//presetting motors

//set pins controlling the rotating derection of the two motors.
//L: left motor;  R: right motor.

#define L_in1 5
#define L_in2 6
#define R_in1 9
#define R_in2 10


//Presetting the electric arm

//Setting servos

#include <Servo.h>
Servo claw, updown1, updown2, lr;     //lr for left and right position servo

//define the pins of each servo
#define pinClaw 2
#define pinUD1 4
#define pinUD2 7
#define pinLR 8

int pos = 90;  //pos: position of lr

bool flag = true, flag2 = true;


void setup(){
  
  //setting up PS2 controller

  //Serial.begin(115200);

  delay(500);  //added delay to give wireless ps2 module some time to startup, before configuring it
   
  //setup pins and settings: GamePad(clock, command, attention, data, Pressures?, Rumble?) check for error
  error = ps2x.config_gamepad(PS2_CLK, PS2_CMD, PS2_SEL, PS2_DAT, pressures, rumble);




  //setting pins about motors

  pinMode(L_in1, OUTPUT);
  pinMode(L_in2, OUTPUT);
  pinMode(R_in1, OUTPUT);
  pinMode(R_in2, OUTPUT);




  //setting the electric arm
  claw.attach(pinClaw);
  updown1.attach(pinUD1);
  updown2.attach(pinUD2);
  lr.attach(pinLR);
  updown1.write(0);
  updown2.write(108);
  releaseBall();
  lr.write(pos);
  
}

void loop() {
  /* You must Read Gamepad to get new values and set vibration values
     ps2x.read_gamepad(small motor on/off, larger motor strength from 0-255)
     if you don't enable the rumble, use ps2x.read_gamepad(); with no values
     You should call this at least once a second
   */  

  ps2x.read_gamepad(false, vibrate); //read controller and set large motor to spin at 'vibrate' speed
  
  //Controls about the movement of the car

  if(ps2x.Button(PSB_PAD_UP)){      //will be TRUE as long as button is pressed
    forward();
  }
  else if(ps2x.Button(PSB_PAD_DOWN)){
    backward();
  }
  else if(ps2x.Button(PSB_PAD_LEFT)){
    turnLeft();
  }
  else if(ps2x.Button(PSB_PAD_RIGHT)){
    turnRight();
  }
  else {
    _stop();
  }

  //Controls about the electric arm

  //Controls about catching big balls
                
  if(ps2x.ButtonPressed(PSB_L1)) {//will be TRUE if button was JUST pressed
    //Serial.println("Catch Ball");
    catchBall();
  }
  if(ps2x.ButtonPressed(PSB_R1)) {
    //Serial.println("Release Ball");
    releaseBall();
  }

  //Controls about the movement of the electric arm


  if(ps2x.ButtonPressed(PSB_TRIANGLE)){      //TRIANGLE is at the top
    //Serial.println("Arm Up");
    armUp();
  }
  else if(ps2x.ButtonPressed(PSB_CROSS)){      //CROSS is at the bottom
    //Serial.println("Arm Down");
    armDown();
  }
  else if(ps2x.Button(PSB_SQUARE)){      //SQUARE is on the left
    //Serial.println("Arm Left");
    armLeft();
  }
  else if(ps2x.Button(PSB_CIRCLE)){      //CIRCLE is on the right
    //Serial.println("Arm Right");
    armRight();
  }

  delay(30);  

}
